@@ -46,7 +46,7 @@ class ServiceRequestMessage(Message):
     identifier = 'REQUEST'
 
     def __init__(self, sender_id, receiver_id, target_comp_id, target_method, *args, **keywords):
-        Message.__init__(self, sender_id, receiver_id)
+        super().__init__(sender_id, receiver_id)
         self.target_comp_id = target_comp_id
         self.target_method = target_method
         self.args = args
@@ -70,12 +70,16 @@ class ServiceResponseMessage(Message):
     identifier = 'RESPONSE'
 
     def __init__(self, sender_id, receiver_id, request_msg_id, status, *args):
-        Message.__init__(self, sender_id, receiver_id)
+        super().__init__(sender_id, receiver_id)
         self.request_msg_id = request_msg_id
         self.status = status
         self.args = args
         self.message_id = self.get_message_id()
 
+    def __repr__(self):
+        return (f'ServiceResponseMessage(sender_id={self.sender_id}, receiver_id={self.receiver_id}, request_msg_id={self.request_msg_id},'
+                f'status={self.status}, args={self.args}, message_id={self.message_id})')
+
 
 class MethodInvokeMessage(Message):
     r"""
@@ -92,7 +96,7 @@ class MethodInvokeMessage(Message):
     identifier = 'INVOKE'
 
     def __init__(self, sender_id, receiver_id, call_id, target_method, *args, **keywords):
-        Message.__init__(self, sender_id, receiver_id)
+        super().__init__(sender_id, receiver_id)
         self.call_id = call_id
         self.target_method = target_method
         self.args = args
@@ -115,7 +119,7 @@ class MethodResultMessage(Message):
     identifier = 'RESULT'
 
     def __init__(self, sender_id, receiver_id, call_id, status, *args):
-        Message.__init__(self, sender_id, receiver_id)
+        super().__init__(sender_id, receiver_id)
         self.call_id = call_id
         self.args = args
         self.status = status
