@@ -5,9 +5,10 @@
 import os
 import time
 from math import ceil
-from .ipsExceptions import InsufficientResourcesException, \
-    BadResourceRequestException, \
-    ResourceRequestMismatchException
+from .ipsExceptions import (InsufficientResourcesException,
+                            BadResourceRequestException,
+                            ResourceRequestMismatchException,
+                            ResourceRequestUnequalPartitioningException)
 from .ips_es_spec import eventManager
 from .resourceHelper import getResourceList
 from .node_structure import Node
@@ -34,12 +35,17 @@ class ResourceManager:
         self.CM = None
 
         self.accurateNodes = False
+        self.node_alloc_mode = None
+
+        self.host = None
+
+        self.reporting_file = None
 
         # bookkeeping for allocationa and accounting
         self.nodes = {}
         self.num_nodes = 0
-        self.avail_nodes = list()
-        self.alloc_nodes = list()
+        self.avail_nodes = []
+        self.alloc_nodes = []
         self.total_cores = 0
         self.alloc_cores = 0
         self.avail_cores = 0
@@ -217,7 +223,7 @@ class ResourceManager:
         Print the node tree to ``stdout``.
         """
         print("*** RM.nodeTable ***")
-        for n, i in list(self.nodes.items()):
+        for n, i in self.nodes.items():
             print(n)
             i.print_sockets()
         print("=====================")
@@ -250,7 +256,7 @@ class ResourceManager:
     # RM getAllocation
     # pylint: disable=inconsistent-return-statements
     def get_allocation(self, comp_id, nproc, task_id,
-                       whole_nodes, whole_socks, task_ppn=0):
+                       whole_nodes, whole_socks, task_ppn=0, task_cpp=0):
         """
         Traverse available nodes to return:
 
@@ -310,6 +316,20 @@ class ResourceManager:
         allocation_possible = False
         if whole_nodes:
             allocation_possible, nodes = self.check_whole_node_cap(nproc, ppn)
+
+            if allocation_possible:
+                num_cores = self.cores_per_node
+                max_cpp = num_cores//ppn
+                if task_cpp > 0:
+                    if task_cpp > max_cpp:
+                        self.fwk.warning(f"task cpp ({task_cpp}) exceeds maximum possible for {ppn} procs per node "
+                                         f"with {num_cores} cores per node, using {max_cpp} cpus per proc instead")
+                        cpp = max_cpp
+                    else:
+                        cpp = task_cpp
+                else:
+                    cpp = max_cpp
+
         elif whole_socks:
             allocation_possible, nodes = self.check_whole_sock_cap(nproc, ppn)
         else:
@@ -328,10 +348,15 @@ class ResourceManager:
                 c = ceil(float(nproc) / ppn)
                 raise InsufficientResourcesException(comp_id, task_id,
                                                      c, c - len(self.avail_nodes))
+            if nodes == "unequal":
+                raise ResourceRequestUnequalPartitioningException(comp_id, task_id,
+                                                                  nproc, ppn,
+                                                                  self.total_cores,
+                                                                  self.max_ppn)
         else:
             try:
                 self.processes += nproc
-                k = 0
+                cores_allocated = 0
                 alloc_procs = 0
                 node_file_entries = []
                 if whole_nodes:
@@ -346,10 +371,10 @@ class ResourceManager:
                         self.avail_nodes.remove(n)
                         self.alloc_nodes.append(n)
                         node_file_entries.append((n, cores))
-                        k += procs
-                    self.alloc_cores += k
-                    self.avail_cores -= k
-                    self.active_tasks.update({task_id: (comp_id, nproc, k)})
+                        cores_allocated += procs
+                    self.alloc_cores += cores_allocated
+                    self.avail_cores -= cores_allocated
+                    self.active_tasks.update({task_id: (comp_id, nproc, cores_allocated)})
                 elif whole_socks:
                     # -------------------------------
                     # whole sock allocation
@@ -363,7 +388,7 @@ class ResourceManager:
                                                          whole_socks,
                                                          task_id, comp_id,
                                                          to_alloc)
-                            k += len(cores)
+                            cores_allocated += len(cores)
                             alloc_procs = min([ppn, len(cores)])
                             node_file_entries.append((n, cores))
                             if n not in self.alloc_nodes:
@@ -371,9 +396,9 @@ class ResourceManager:
                                 if node.avail_cores - node.total_cores == 0:
                                     self.avail_nodes.remove(n)
 
-                    self.alloc_cores += k
-                    self.avail_cores -= k
-                    self.active_tasks.update({task_id: (comp_id, nproc, k)})
+                    self.alloc_cores += cores_allocated
+                    self.avail_cores -= cores_allocated
+                    self.active_tasks.update({task_id: (comp_id, nproc, cores_allocated)})
                 else:
                     # -------------------------------
                     # single core allocation
@@ -382,22 +407,22 @@ class ResourceManager:
                         node = self.nodes[n]
                         if node.avail_cores > 0:
                             to_alloc = min([ppn, node.avail_cores,
-                                            nproc - k])
+                                            nproc - cores_allocated])
                             self.fwk.debug("allocate task_id %d node %s %d cores" % (task_id, n, to_alloc))
                             procs, cores = node.allocate(whole_nodes,
                                                          whole_socks,
                                                          task_id, comp_id,
                                                          to_alloc)
-                            k += procs
+                            cores_allocated += procs
                             node_file_entries.append((n, cores))
                             if n not in self.alloc_nodes:
                                 self.alloc_nodes.append(n)
                                 if node.avail_cores - node.total_cores == 0:
                                     self.avail_nodes.remove(n)
 
-                    self.alloc_cores += k
-                    self.avail_cores -= k
-                    self.active_tasks.update({task_id: (comp_id, nproc, k)})
+                    self.alloc_cores += cores_allocated
+                    self.avail_cores -= cores_allocated
+                    self.active_tasks.update({task_id: (comp_id, nproc, cores_allocated)})
             except Exception:
                 print("Available Nodes:")
                 for nm in self.avail_nodes:
@@ -410,7 +435,7 @@ class ResourceManager:
                     print(n.name, n.avail_cores)
                     n.print_sockets()
                 print("\n ***** Neither List!")
-                for nm, n in list(self.nodes.items()):
+                for nm, n in self.nodes.items():
                     if nm not in self.avail_nodes and nm not in self.alloc_nodes:
                         print(nm, n.avail_cores)
                         n.print_sockets()
@@ -418,10 +443,10 @@ class ResourceManager:
 
             if whole_nodes:
                 self.report_RM_status("allocation for task %d using whole nodes" % task_id)
-                return not whole_nodes, nodes, ppn, self.max_ppn, self.accurateNodes
+                return not whole_nodes, nodes, ppn, self.max_ppn, cpp, self.accurateNodes, cores_allocated
             else:
                 self.report_RM_status("allocation for task %d using partial nodes" % task_id)
-                return not whole_nodes, nodes, node_file_entries, ppn, self.max_ppn, self.accurateNodes
+                return not whole_nodes, nodes, node_file_entries, ppn, self.max_ppn, self.accurateNodes, cores_allocated
 
     def check_whole_node_cap(self, nproc, ppn):
         """
@@ -441,13 +466,16 @@ class ResourceManager:
                     whole_cap += ppn
                     nodes.append(n)
                     if whole_cap >= nproc:
-                        return True, nodes
+                        if nproc > ppn and nproc % ppn != 0:
+                            return False, "unequal"
+                        else:
+                            return True, nodes
         except Exception:
             self.fwk.exception("problem in RM.check_whole_node_cap")
             raise
         # check to see if it is possible to satisfy the request
         tot_cap = 0
-        for n in list(self.nodes.values()):
+        for n in self.nodes.values():
             tot_cap += min([ppn, n.total_cores])
             if tot_cap >= nproc:
                 return False, "insufficient"
@@ -491,7 +519,7 @@ class ResourceManager:
             raise
         # check to see if it is possible to satisfy the request
         tot_cap = 0
-        for n in list(self.nodes.values()):
+        for n in self.nodes.values():
             tot_cap += min([ppn, n.total_cores])
             if tot_cap >= nproc:
                 return False, "insufficient"
@@ -538,7 +566,7 @@ class ResourceManager:
             raise
         # check to see if it is possible to satisfy the request
         tot_cap = 0
-        for n in list(self.nodes.values()):
+        for n in self.nodes.values():
             tot_cap += min([ppn, n.total_cores])
             if tot_cap >= nproc:
                 return False, "insufficient"
@@ -558,7 +586,7 @@ class ResourceManager:
 
         o, nproc, num_cores = self.active_tasks[task_id]
         tot_avc = 0
-        for n, node in list(self.nodes.items()):
+        for n, node in self.nodes.items():
             if task_id in node.task_ids:
                 node.release(task_id, o)
                 if node.avail_cores > 0 and n not in self.avail_nodes:
